@@ -413,13 +413,10 @@ void labeldefaults(labelptr newlabel, u_char dopin, int x, int y)
    newlabel->string->data.font = areawin->psfont;
    newlabel->string->nextpart = NULL;
 
-   newlabel->pin = False;
-   if (areawin->schemon) {
-      newlabel->pin = dopin;
-      if (dopin == LOCAL) newlabel->color = LOCALPINCOLOR;
-      else if (dopin == GLOBAL) newlabel->color = GLOBALPINCOLOR;
-      else if (dopin == INFO) newlabel->color = INFOLABELCOLOR;
-   }
+   newlabel->pin = dopin;
+   if (dopin == LOCAL) newlabel->color = LOCALPINCOLOR;
+   else if (dopin == GLOBAL) newlabel->color = GLOBALPINCOLOR;
+   else if (dopin == INFO) newlabel->color = INFOLABELCOLOR;
 
    newlabel->justify = areawin->justify;
    newlabel->position.x = x;
@@ -525,7 +522,7 @@ Boolean labeltext(int keypressed, char *clientdata)
 
    curlabel = TOLABEL(EDITPART);
 
-   if (curlabel == NULL || textpos <= 0) {
+   if (curlabel == NULL || curlabel->type != LABEL || textpos <= 0) {
       Wprintf("Error:  Bad label string");
       return FALSE;
    }
@@ -535,7 +532,7 @@ Boolean labeltext(int keypressed, char *clientdata)
 
    UDrawTLine(curlabel);
 
-   if (r = isbound(keypressed, XCF_Text_Delete)) {
+   if (clientdata != NULL && keypressed == TEXT_DELETE) {
       if (textpos > 1) {
          int curloc, strpos;
          stringpart *strptr;
@@ -571,7 +568,7 @@ Boolean labeltext(int keypressed, char *clientdata)
          do_redraw = True;
       }
    }
-   else if (r = isbound(keypressed, XCF_Text_Delete_Param)) {
+   else if (clientdata != NULL && keypressed == TEXT_DEL_PARAM) {
       if (textpos > 1) {
          int curloc, strpos;
          stringpart *strptr;
@@ -588,7 +585,7 @@ Boolean labeltext(int keypressed, char *clientdata)
 	 }
       }
    }
-   else if (r = isbound(keypressed, XCF_Text_Return)) {
+   else if (clientdata != NULL && keypressed == TEXT_RETURN) {
       Boolean hasstuff = False;   /* Check for null string */
       stringpart *tmppos;
 
@@ -640,26 +637,27 @@ Boolean labeltext(int keypressed, char *clientdata)
 	  eventmode = NORMAL_MODE;
       }
       else if (eventmode == CATTEXT_MODE) {
+	 objectptr libobj;
+	 stringpart *oldname;
 
-         /* set name of object to new string */
+	 /* Get the library object whose name matches the original string */
+	 oldname = get_original_string(curlabel);
+	 libobj = NameToObject(oldname->nextpart->data.string, NULL, FALSE);
+	 if (libobj != NULL) {
+
+            /* set name of object to new string */
+
+	    strcpy(libobj->name, curlabel->string->nextpart->data.string);
 
-	 areawin->save.y = curlabel->position.y + 100;
-	 areawin->save.x = curlabel->position.x;
-	 select_element(OBJINST);
-	 if (areawin->selects == 1) {  /* this should be true! */
-	    short *selptr = areawin->selectlist + areawin->selects - 1;
-	    objinstptr selobj = SELTOOBJINST(selptr);
-	    strcpy(selobj->thisobject->name, curlabel->string->nextpart->data.string);
 	    /* If checkname() alters the name, it has to be copied back to */
 	    /* the catalog label for the object.			   */
 
-	    if (checkname(selobj->thisobject)) {
+	    if (checkname(libobj)) {
 	       undrawtext(curlabel);
 	       curlabel->string->nextpart->data.string = (char *)realloc(
 			curlabel->string->nextpart->data.string,
 		  	(strlen(_STR) + 1) * sizeof(char));
-	       strcpy(curlabel->string->nextpart->data.string,
-			selobj->thisobject->name);
+	       strcpy(curlabel->string->nextpart->data.string, libobj->name);
                XcSetFunction(GXcopy);
 	       redrawtext(curlabel);
 	    }
@@ -682,8 +680,7 @@ Boolean labeltext(int keypressed, char *clientdata)
 	 /* name is unique, change every pin in the matching symbol/	*/
 	 /* schematic to match the new text.				*/
 
-	 if ((areawin->schemon == True) && (curlabel->pin == LOCAL) && 
-		(topobject->symschem != NULL)) {
+	 if ((curlabel->pin == LOCAL) && (topobject->symschem != NULL)) {
 	    if ((findlabelcopy(curlabel, labelbuf) == NULL)
 			&& (findlabelcopy(curlabel, curlabel->string) == NULL)) {
 	       changeotherpins(curlabel, labelbuf);
@@ -705,13 +702,13 @@ Boolean labeltext(int keypressed, char *clientdata)
 
       return r;
    }
-   else if (r = isbound(keypressed, XCF_Text_Right)) {
+   else if (clientdata != NULL && keypressed == TEXT_RIGHT) {
       if (curpos != NULL) textpos++;
    }
-   else if (r = isbound(keypressed, XCF_Text_Left)) {
+   else if (clientdata != NULL && keypressed == TEXT_LEFT) {
       if (textpos > 1) textpos--;
    }
-   else if (r = isbound(keypressed, XCF_Text_Down)) {
+   else if (clientdata != NULL && keypressed == TEXT_DOWN) {
       while (curpos != NULL) {
 	 textpos++;
 	 curpos = findstringpart(textpos, &locpos, curlabel->string,
@@ -721,7 +718,7 @@ Boolean labeltext(int keypressed, char *clientdata)
 	       break;
       }
    }
-   else if (r = isbound(keypressed, XCF_Text_Up)) {
+   else if (clientdata != NULL && keypressed == TEXT_UP) {
       while (textpos > 1) {
 	 textpos--;
 	 curpos = findstringpart(textpos, &locpos, curlabel->string,
@@ -732,11 +729,11 @@ Boolean labeltext(int keypressed, char *clientdata)
 	 }
       }
    }
-   else if (r = isbound(keypressed, XCF_Text_Home))
+   else if (clientdata != NULL && keypressed == TEXT_HOME)
       textpos = 1;
-   else if (r = isbound(keypressed, XCF_Text_End))
+   else if (clientdata != NULL && keypressed == TEXT_END)
       textpos = stringlength(curlabel->string, True, areawin->topinstance);
-   else if (r = isbound(keypressed, XCF_Text_Split)) {
+   else if (clientdata != NULL && keypressed == TEXT_SPLIT) {
       labelptr *newlabel;
       XPoint points[4], points1[4], points2[4];
 
@@ -781,7 +778,7 @@ Boolean labeltext(int keypressed, char *clientdata)
 
    /* Write a font designator or other control into the string */
 
-   if (clientdata != NULL) {
+   else if (clientdata != NULL) {
       oparamptr ops;
       stringpart *newpart;
       Boolean errcond = False;
@@ -927,10 +924,7 @@ Boolean labeltext(int keypressed, char *clientdata)
 
 void textreturn()
 {
-   int rkey;
-
-   rkey = firstbinding(XCF_Text_Return);
-   labeltext(rkey, NULL);
+   labeltext(TEXT_RETURN, (char *)1);
 }
 
 /*-------------------------------------*/
@@ -952,7 +946,11 @@ void rejustify(short mode)
       jsave = curlabel->justify;
       curlabel->justify = transjust[mode] |
 		(curlabel->justify & NONJUSTFIELD);
-      if (jsave != curlabel->justify) changed = True;
+      if (jsave != curlabel->justify) {
+	 register_for_undo(XCF_Justify, UNDO_MORE, areawin->topinstance,
+			(genericptr)curlabel, (int)jsave);
+	 changed = True;
+      }
       redrawtext(curlabel);
       UDrawTLine(curlabel);
 
@@ -967,7 +965,11 @@ void rejustify(short mode)
 	    undrawtext(curlabel);
       	    curlabel->justify = transjust[mode] |
 		(curlabel->justify & NONJUSTFIELD);
-            if (jsave != curlabel->justify) changed = True;
+            if (jsave != curlabel->justify) {
+	       register_for_undo(XCF_Justify, UNDO_MORE, areawin->topinstance,
+			(genericptr)curlabel, (int)jsave);
+	       changed = True;
+	    }
 	 }
       }
       if (eventmode != MOVE_MODE && eventmode != COPY_MODE)
