@@ -12,10 +12,8 @@
 #include <string.h>
 #include <math.h>
 
-#ifndef _MSC_VER
 #include <X11/Intrinsic.h>
 #include <X11/StringDefs.h>
-#endif
 
 #ifdef OPENGL
 #include <GL/gl.h>
@@ -44,7 +42,7 @@
 
 extern Display  *dpy;
 extern Globaldata xobjs;
-extern Clientdata areastruct;
+extern XCWindowData *areawin;
 
 /*----------------------------------------------------------------------*/
 /* Recursive search for graphic images in an object.			*/
@@ -132,6 +130,9 @@ void transform_graphic(graphicptr gp)
 
     scale = gp->scale * UTopTransScale(1.0);
 
+    if (gp->rotation == 360) gp->rotation = 0;
+    else if (gp->rotation < 0) gp->rotation += 360;
+
     cosr = cos(RADFAC * gp->rotation);
     sinr = sin(RADFAC * gp->rotation);
     c = (int)(8192 * cosr / scale);
@@ -161,8 +162,16 @@ void transform_graphic(graphicptr gp)
 			0, 0, twidth, theight, 8, 0);
     gp->target->data = (char *)calloc(theight, gp->target->bytes_per_line);
 
+    if (gp->target->data == (char *)NULL) {
+       XDestroyImage(gp->target);
+       gp->target = (XImage *)NULL;
+       gp->clipmask = (Pixmap)NULL;
+       gp->valid = FALSE;
+       return;
+    }
+
     if (gp->rotation != 0) {
-       gp->clipmask = XCreatePixmap(dpy, areastruct.areawin, twidth, theight, 1);
+       gp->clipmask = XCreatePixmap(dpy, areawin->window, twidth, theight, 1);
        if (cmgc == (GC)NULL) {
           XGCValues values;
           values.foreground = 0;
@@ -207,6 +216,7 @@ void UDrawGraphic(graphicptr gp)
     int width, height;
 
     if (gp->valid == FALSE) transform_graphic(gp);
+    if (gp->valid == FALSE) return;			/* Error condition */
 
     user_to_window(gp->position, &ppt);
 
@@ -214,15 +224,16 @@ void UDrawGraphic(graphicptr gp)
     ppt.y -= (gp->target->height >> 1);
 
     if (gp->clipmask != (Pixmap)NULL) {
-       XSetClipOrigin(dpy, areastruct.gc, ppt.x, ppt.y);
-       XSetClipMask(dpy, areastruct.gc, gp->clipmask);
+       XSetClipOrigin(dpy, areawin->gc, ppt.x, ppt.y);
+       XSetClipMask(dpy, areawin->gc, gp->clipmask);
     }
 
-    XPutImage(dpy, areastruct.areawin, areastruct.gc,
-		gp->target, 0, 0, ppt.x, ppt.y, gp->target->width, gp->target->height);
+    XPutImage(dpy, areawin->window, areawin->gc,
+		gp->target, 0, 0, ppt.x, ppt.y, gp->target->width,
+		gp->target->height);
 
     if (gp->clipmask != (Pixmap)NULL)
-       XSetClipMask(dpy, areastruct.gc, None);
+       XSetClipMask(dpy, areawin->gc, None);
 }
 
 /*----------------------------------------------------------------------*/
@@ -281,7 +292,7 @@ graphicptr new_graphic(objinstptr destinst, char *filename, int px, int py)
        u_long i;
     } pixel;
 
-    locdestinst = (destinst == NULL) ? areastruct.topinstance : destinst;
+    locdestinst = (destinst == NULL) ? areawin->topinstance : destinst;
     destobject = locdestinst->thisobject;
 
     /* Check the existing list of images.  If there is a match,	*/
@@ -387,7 +398,7 @@ graphicptr new_graphic(objinstptr destinst, char *filename, int px, int py)
     updatepagebounds(destobject);
     incr_changes(destobject);
 
-    register_for_undo(XCF_Graphic, UNDO_DONE, areastruct.topinstance, *gp);
+    register_for_undo(XCF_Graphic, UNDO_DONE, areawin->topinstance, *gp);
 
     return *gp;
 }
