@@ -220,7 +220,7 @@ void printhelppix()
        vtmp = t1 + t2 + 5;
        if (vtmp > lineheight) lineheight = vtmp;
 
-       bindings = binding_to_string(-1, helptext[i].function);
+       bindings = function_binding_to_string(0, helptext[i].function);
 
        /* Limit list to three key bindings per line */
        bptr = bindings;
@@ -273,7 +273,7 @@ void printhelppix()
        }
        XDrawString(dpy, helppix, hgc, 7, vtmp, helptext[i].text,
 		strlen(helptext[i].text));
-       bindings = binding_to_string(-1, helptext[i].function);
+       bindings = function_binding_to_string(0, helptext[i].function);
        bptr = bindings;
        while (bptr != NULL) {
 	  cptr = bptr;
