@@ -16,6 +16,9 @@ extern void free_undo_record(Undoptr);
 extern void free_redo_record(Undoptr);
 extern stringpart *get_original_string(labelptr);
 extern short *recover_selectlist(Undoptr);
+extern void free_selection(uselection *);
+extern uselection *remember_selection(objinstptr, short *, int);
+extern short *regen_selection(objinstptr, uselection *);
 #ifndef TCL_WRAPPER
 extern void undo_call(xcWidget, caddr_t, caddr_t);
 extern void redo_call(xcWidget, caddr_t, caddr_t);
@@ -31,6 +34,7 @@ extern Tk_EventProc *xctk_dragfilebox(ClientData, XEvent *);
 extern int XcTagCallback(Tcl_Interp *, int, Tcl_Obj *CONST objv[]);
 extern Tcl_Obj *evaluate_raw(oparamptr, int *);
 extern char *TCL_to_PS(char *);
+extern XCWindowData *GUI_init(int, Tcl_Obj *CONST objv[]);
 #endif
 
 extern char *evaluate_expr(oparamptr, objinstptr);
@@ -110,6 +114,7 @@ extern void wire_op(int, int ,int);
 
 extern Boolean recursefind(objectptr, objectptr);
 extern void transferselects();
+extern void select_invalidate_netlist();
 extern void newmatrix();
 extern void setpage(Boolean);
 extern int changepage(short);
@@ -143,7 +148,8 @@ extern void nextarccycle(arcptr, short);
 extern void buttonhandler(xcWidget, caddr_t, XButtonEvent *);
 extern void keyhandler(xcWidget, caddr_t, XKeyEvent *);
 extern Boolean compatible_function(int);
-extern void eventdispatch(int, int, int);
+extern int eventdispatch(int, int, int);
+extern int functiondispatch(int, short, int, int);
 extern void releasehandler(xcWidget, caddr_t, XKeyEvent *);
 extern void setsnap(short);
 extern void snapelement();
@@ -157,17 +163,17 @@ extern XPoint *pathclosepoint(pathptr, XPoint *);
 extern void placeselects(short, short, XPoint *);
 extern void drag(int, int);
 extern void xlib_drag(xcWidget, caddr_t, XEvent *);
-extern void elemrotate(genericptr *, short);
-extern void elementrotate(short);
+extern void elemrotate(genericptr *, short, int, int);
+extern void elementrotate(short, int, int);
 extern void edit(int, int);
 extern void pathedit(genericptr *, short);
 extern void xc_lower(short *);
 extern void xc_raise(short *);
 extern void exchange();
-extern void elhflip(genericptr *);
-extern void elvflip(genericptr *);
-extern void elementflip();
-extern void elementvflip();
+extern void elhflip(genericptr *, int, int);
+extern void elvflip(genericptr *, int, int);
+extern void elementflip(int, int);
+extern void elementvflip(int, int);
 #ifdef TCL_WRAPPER
 extern xcTimeOutProc makepress(caddr_t);
 #else
@@ -255,7 +261,8 @@ extern void loadblib();
 extern void getlib(xcWidget, caddr_t, caddr_t);
 extern void getuserlib(xcWidget, caddr_t, caddr_t);
 extern Boolean loadlibrary(short);
-extern void startloadfile();
+extern void startloadfile(int);
+extern void normalloadfile();
 extern void importfile();
 extern Boolean loadfile(short, int);
 extern void readlabel(objectptr, char *, stringpart **);
@@ -403,23 +410,23 @@ extern void printhelp(xcWidget);
 
 /* from keybindings.c */
 
-extern int firstbinding(int);
-extern Boolean ismacro(int);
-extern Boolean isbound(int, int);
-extern Boolean isnbound(int, int, short *);
-extern int boundfunction(int, int);
+extern int firstbinding(xcWidget, int);
+extern Boolean ismacro(xcWidget, int);
+extern int boundfunction(xcWidget, int, short *);
 extern int string_to_func(const char *, short *);
 extern int string_to_key(const char *);
-extern char *binding_to_string(int, int);
+extern char *function_binding_to_string(xcWidget, int);
+extern char *key_binding_to_string(xcWidget, int);
+extern char *compat_key_to_string(xcWidget, int);
 extern char *func_to_string(int);
 extern char *key_to_string(int);
 extern void printeditbindings();
-extern int add_vbinding(int, int, short);
-extern int add_binding(int, int);
-extern int add_keybinding(const char *, const char *);
+extern int add_vbinding(xcWidget, int, int, short);
+extern int add_binding(xcWidget, int, int);
+extern int add_keybinding(xcWidget, const char *, const char *);
 extern void default_keybindings();
-extern int remove_binding(int, int);
-extern void remove_keybinding(const char *, const char *);
+extern int remove_binding(xcWidget, int, int);
+extern void remove_keybinding(xcWidget, const char *, const char *);
 
 #ifndef TCL_WRAPPER
 extern void mode_rebinding(int, int);
@@ -433,8 +440,14 @@ extern void catreturn();
 extern int pageposition(short, int, int, int);
 extern short pagelinks();
 extern short *pagetotals(int, short);
+extern Boolean is_virtual(objinstptr);
 extern int is_page(objectptr);
 extern int is_library(objectptr);
+extern int name_to_library(char *);
+extern void lib_set_changes();
+extern void lib_mark_changed(int);
+extern int libfindobject(objectptr, int *);
+extern int libmoveobject(objectptr, int);
 extern void pagecat_op(int, int, int);
 extern void pageinstpos(short, short, objinstptr, int, int, int, int);
 extern objinstptr newpageinst(objectptr);
@@ -573,8 +586,8 @@ extern void NameToPosition(objinstptr, labelptr, XPoint *);
 extern XPoint *NetToPosition(int, objectptr);
 extern void invalidate_netlist(objectptr);
 extern void remove_netlist_element(objectptr, genericptr);
-extern int updatenets(objinstptr);
-extern void createnets(objinstptr);
+extern int updatenets(objinstptr, Boolean);
+extern void createnets(objinstptr, Boolean);
 extern void destroynets();
 extern Boolean nonnetwork(polyptr);
 extern int globalmax();
@@ -636,6 +649,9 @@ extern void destroynets(objectptr);
 extern int  cleartraversed(objectptr);
 extern int  checkvalid(objectptr);
 extern void clearlocalpins(objectptr);
+extern void append_included(char *);
+extern Boolean check_included(char *);
+extern void free_included();
 
 /* from parameter.c: */ 
 
@@ -748,7 +764,6 @@ extern Boolean render_client();
 extern objectptr NameToPageObject(char *, objinstptr *, int *);
 extern objectptr NameToObject(char *, objinstptr *, Boolean);
 extern void callwritenet(xcWidget, pointertype, caddr_t);
-extern void doxschema(xcWidget, pointertype, caddr_t);
 extern void startconnect(xcWidget, caddr_t, caddr_t);
 extern void connectivity(xcWidget, caddr_t, caddr_t);
 extern Boolean setobjecttype(objectptr);
@@ -773,6 +788,8 @@ extern void xlib_swapschem(xcWidget, pointertype, caddr_t);
 
 /* from selection.c: */
 
+extern void enable_selects(objectptr, short *, int);
+extern void disable_selects(objectptr, short *, int);
 extern void selectfilter(xcWidget, pointertype, caddr_t);
 extern Boolean checkselect(short);
 extern void geneasydraw(short, int, objectptr, objinstptr);
@@ -801,6 +818,7 @@ extern void trackselarea();
 extern Boolean hasparameter(labelptr);
 extern void drawparamlabels(labelptr, short);
 extern stringpart *nextstringpart(stringpart *, objinstptr);
+extern stringpart *nextstringpartrecompute(stringpart *, objinstptr);
 extern stringpart *makesegment(stringpart **, stringpart *);
 extern stringpart *splitstring(int, stringpart **, objinstptr);
 extern stringpart *mergestring(stringpart *);
@@ -845,6 +863,7 @@ extern void W2printf(char *, ...);
 extern void W3printf(char *, ...);
 
 extern XCWindowData *create_new_window();
+extern void delete_window(XCWindowDataPtr);
 extern void printeventmode();
 extern void popupprompt(xcWidget, char *, char *, void (*function)(),
                         buttonsave *, const char *);
