@@ -92,19 +92,18 @@ short execcommand(short pflags, char *cmdptr)
       sscanf(argptr, "%149s", _STR);
       if (!strncmp(_STR, "grid", 4)) {
 	 areawin->gridon = a ? True : False;
-	 toggle(GridGridButton, &areawin->gridon, NULL);
+	 toggle(GridGridButton, (pointertype)&areawin->gridon, NULL);
       }
       else if (!strncmp(_STR, "snap", 4) || !strncmp(_STR, "snap-to", 4)) {
 	 areawin->snapto = a ? True : False;
-	 toggle(SnaptoSnaptoButton, &areawin->snapto, NULL);
+	 toggle(SnaptoSnaptoButton, (pointertype)&areawin->snapto, NULL);
       }
       else if (!strcmp(_STR, "axis") || !strcmp(_STR, "axes")) {
 	 areawin->axeson = a ? True : False;
-	 toggle(GridAxesButton, &areawin->axeson, NULL);
+	 toggle(GridAxesButton, (pointertype)&areawin->axeson, NULL);
       }
       else if (!strcmp(_STR, "xschema") || !strcmp(_STR, "schema")) {
-	 areawin->schemon = a ? True : False;
-	 doxschema(OptionsEnableXSchemaButton, 1, NULL);
+	 /* Do nothing---retained for backward compatibility only */
       }
 #ifdef HAVE_XPM
       else if (!strcmp(_STR, "toolbar")) {
@@ -147,7 +146,7 @@ short execcommand(short pflags, char *cmdptr)
       int savepage = areawin->page;
       if (sscanf(argptr, "%249s %d", _STR, &pageno) >= 1) {
 	 if (pageno != savepage) newpage(pageno);
-	 startloadfile();
+	 startloadfile(-1);
 	 if (pageno != savepage) newpage(savepage);
       }
       else
@@ -219,7 +218,10 @@ short execcommand(short pflags, char *cmdptr)
 	    keywstate = -1;
 	    func = string_to_func(_STR, NULL);
 	 }
-	 binding = binding_to_string(keywstate, func);
+	 if (keywstate == -1)
+	    binding = function_binding_to_string(0, func);
+	 else
+	    binding = key_binding_to_string(0, keywstate);
 	 Wprintf("%s", binding);
 	 free(binding);
       }
@@ -228,7 +230,7 @@ short execcommand(short pflags, char *cmdptr)
       else {
 	 /* Use entire line after 1st argument, so multiple words are allowed */
 	 sptr = argptr + strlen(_STR);
-         if (add_keybinding(_STR, sptr) < 0) {
+         if (add_keybinding(areawin->area, _STR, sptr) < 0) {
 	    Wprintf("Function \"%s\" is not known\n", sptr);
 	 }
       }
@@ -242,7 +244,7 @@ short execcommand(short pflags, char *cmdptr)
          flags |= KEYOVERRIDE;
       }
       sscanf(argptr, "%149s %249s", _STR, _STR2);
-      remove_keybinding(_STR, _STR2);
+      remove_keybinding(areawin->area, _STR, _STR2);
    }
 
    /* beep mode */
@@ -318,7 +320,7 @@ short execcommand(short pflags, char *cmdptr)
 	 sscanf(argptr, "%*s %49s", value);
 	 if (!strcmp(value, "inverse") || !strcmp(value, "2"))
 	    areawin->invert = False;
-	 inversecolor(NULL, &areawin->invert, NULL);
+	 inversecolor(NULL, (pointertype)&areawin->invert, NULL);
       }
       else if (!strncmp(argptr, "coordstyle", 10)) {
 	 sscanf(argptr, "%*s %49s", value);
