@@ -539,10 +539,10 @@ int renderbackground()
    defscale = (xobjs.pagelist[areawin->page]->coordstyle == CM) ?
 	CMSCALE : INCHSCALE;
 
-   psnorm = (*areawin->vscale) * (1.0 / defscale) * devres;
+   psnorm = areawin->vscale * (1.0 / defscale) * devres;
 
-   psxpos = (float)(-areawin->pcorner->x) * (*areawin->vscale) * devres;
-   psypos = (float)(-areawin->pcorner->y) * (*areawin->vscale) * devres
+   psxpos = (float)(-areawin->pcorner.x) * areawin->vscale * devres;
+   psypos = (float)(-areawin->pcorner.y) * areawin->vscale * devres
 		+ ((float)areawin->height / 12.0);
 
    /* Conditions for re-rendering:  Must have a background specified */
