@@ -44,6 +44,37 @@ extern XCWindowData *areawin;
 extern char _STR[150];
 extern short textpos, textend;
 
+/*----------------------------------------------------------------------*/
+/* Prevent a list of elements from being selected.			*/
+/*----------------------------------------------------------------------*/
+
+void disable_selects(objectptr thisobject, short *selectlist, int selects)
+{
+   genericptr genptr;
+   short *i;
+
+   for (i = selectlist; i < selectlist + selects; i++) {
+      genptr = *(thisobject->plist + *i);
+      genptr->type |= SELECT_HIDE;
+   }
+}
+
+/*----------------------------------------------------------------------*/
+/* Allow a list of elements to be selected, if they were disabled using	*/
+/* the disable_selects() routine.					*/
+/*----------------------------------------------------------------------*/
+
+void enable_selects(objectptr thisobject, short *selectlist, int selects)
+{
+   genericptr genptr;
+   short *i;
+
+   for (i = selectlist; i < selectlist + selects; i++) {
+      genptr = *(thisobject->plist + *i);
+      genptr->type &= ~(SELECT_HIDE);
+   }
+}
+
 /*----------------------------------------------------------------------*/
 /* Change filter to determine what types can be selected		*/
 /*----------------------------------------------------------------------*/
