@@ -201,7 +201,7 @@ stringpart *splitstring(int tpos, stringpart **strtop, objinstptr localinst)
 /* Get the next string part, linking to a paramter if necessary		*/
 /*----------------------------------------------------------------------*/
 
-stringpart *nextstringpart(stringpart *strptr, objinstptr thisinst)
+stringpart *nextstringpartrecompute(stringpart *strptr, objinstptr thisinst)
 {
    stringpart *nextptr = strptr->nextpart;
 
@@ -229,7 +229,7 @@ stringpart *nextstringpart(stringpart *strptr, objinstptr thisinst)
 /* when encountered.  Use the previously generated result.		*/
 /*----------------------------------------------------------------------*/
 
-stringpart *nextstringpartnorecompute(stringpart *strptr, objinstptr thisinst)
+stringpart *nextstringpart(stringpart *strptr, objinstptr thisinst)
 {
    stringpart *nextptr = strptr->nextpart;
 
@@ -302,7 +302,8 @@ stringpart *deletestring(stringpart *dstr, stringpart **strtop, objinstptr thisi
       else
 	 strptr->nextpart = dstr->nextpart;
    }
-   if (dstr->type == TEXT_STRING) free(dstr->data.string);
+   if (dstr->type == TEXT_STRING)
+      free(dstr->data.string);
    free(dstr);
 
    /* attempt to merge, if legal */
@@ -385,8 +386,12 @@ stringpart *linkstring(objinstptr localinst, stringpart *strstart,
          tmpptr = makesegment(&promote, NULL);
          tmpptr->type = PARAM_END;
       }
-      else
-	 free(promote->data.string);
+      else {
+	 if (promote->data.string != NULL) {
+	    free(promote->data.string);
+	    promote->data.string = NULL;
+	 }
+      }
 
       /* Promote numerical type to string */
       if (ops->type == XC_INT) {
@@ -404,13 +409,14 @@ stringpart *linkstring(objinstptr localinst, stringpart *strstart,
 	 if (!compute_exprs && (ips = match_instance_param(localinst, key))
 		!= NULL && (ips->type == XC_STRING)) {
 	    nextptr = ips->parameter.string;
-	    /* This could probably be done better. . . hack to keep  */
-	    /* free() from operating twice on the same memory block. */
-	    promote->data.string = (char *)malloc(1);
+	    promote->data.string = NULL;
 	 }
 	 else {
 	    promote->data.string = evaluate_expr(ops, localinst);
-            nextptr = promote;
+	    if (promote->data.string != NULL)
+               nextptr = promote;
+	    else
+	       nextptr = NULL;
 	 }
       }
    }
@@ -517,7 +523,7 @@ static char *nonprint[] = {
 	"Tab_Stop", "Tab_Forward", "Tab_Backward",
 	"Halfspace", "Quarterspace", "<Return>",
 	"Font", "Scale", "Color", "Kern", 
-        "Parameter", ">", "Error"};
+        "Parameter", ">", "Net_Name", "Error"};
 
 /*----------------------------------------------------------------------*/
 /* charprint():  							*/
@@ -1399,10 +1405,7 @@ void UDrawString(labelptr drawlabel, int passcolor, objinstptr localinst)
    /* them from the circuit point to which they attach.  */
 
    if (drawlabel->pin) {
-      if (!areawin->schemon)
-	 goto enddraw;	/* Don't draw pins when schematic capture is off */
-      else
-	 pinadjust(tmpjust, &(newpoint.x), &(newpoint.y), 1);
+      pinadjust(tmpjust, &(newpoint.x), &(newpoint.y), 1);
    }
 
    oldx = newpoint.x;
@@ -1423,7 +1426,7 @@ void UDrawString(labelptr drawlabel, int passcolor, objinstptr localinst)
 
        pos = 0;
        for (strptr = drawlabel->string; strptr != NULL;
-		strptr = nextstringpartnorecompute(strptr, localinst)) {
+		strptr = nextstringpart(strptr, localinst)) {
 
 	  /* All segments other than text cancel any	*/
 	  /* existing overline/underline in effect.	*/
@@ -1558,7 +1561,8 @@ void UDrawString(labelptr drawlabel, int passcolor, objinstptr localinst)
 		} break;
 
 	     case TEXT_STRING:
-		for (textptr = strptr->data.string; textptr && *textptr != '\0'; textptr++) {
+		for (textptr = strptr->data.string; textptr && *textptr != '\0';
+			textptr++) {
 		   pos++;
 		   UPushCTM();
 		   UPreMultCTM(DCTM, newpoint, tmpscale, 0);
@@ -1594,7 +1598,7 @@ enddraw:
 
    UPopCTM();
 
-   if (drawlabel->pin && areawin->schemon) UDrawXDown(drawlabel);
+   if (drawlabel->pin) UDrawXDown(drawlabel);
 
    if ((defaultcolor != DOFORALL) && (passcolor != curcolor)) {
       XTopSetForeground(passcolor);
