@@ -365,7 +365,7 @@ enum loadmodes {IMPORT = 1, PSBKGROUND, SCRIPT, RECOVER,
 #define PARAM_START	17  /* bounds a parameter; data = param key	*/
 #define PARAM_END	18  /* bounds a parameter; no data 		*/
 
-/* Actions translated to keystates */
+/* Actions translated to keystates (numbering continues from above) */
 
 #define TEXT_RETURN	19
 #define TEXT_HOME	20
@@ -463,6 +463,7 @@ enum loadmodes {IMPORT = 1, PSBKGROUND, SCRIPT, RECOVER,
 #define TRIVIAL 2		/* Symbol as non-schematic element */
 #define SYMBOL 3		/* Symbol associated with a schematic */
 #define FUNDAMENTAL 4		/* Standalone symbol */
+#define NONETWORK 5		/* Do not netlist this object */
 
 #define LOCAL 1
 #define GLOBAL 2
@@ -514,7 +515,7 @@ enum loadmodes {IMPORT = 1, PSBKGROUND, SCRIPT, RECOVER,
 #define DEFAULTCURSOR	(*areawin->defaultcursor)
 
 /*----------------------------------------------------------------------*/
-/* selection-mechanism structures					*/
+/* integer and floating-point coordinate list structures		*/
 /*----------------------------------------------------------------------*/
 
 typedef XPoint* pointlist;
@@ -614,6 +615,16 @@ typedef struct {
    eparamptr	passed;
 } generic, *genericptr;		/* (convenience function for retypecasting) */
 
+/*----------------------------------------------------------------------*/
+/* selection-mechanism structures					*/
+/*----------------------------------------------------------------------*/
+
+typedef struct {
+   short number;
+   genericptr *element;
+   short *idx;
+} uselection;
+
 /*----------------------------------------------------------------------*/
 /* Bounding box								*/
 /*----------------------------------------------------------------------*/
@@ -1005,7 +1016,7 @@ typedef struct _alias {
 #define xcScreen			Tk_Screen
 #define xcParent			Tk_Parent
 #define xcDispatchEvent(a)		Tk_HandleEvent(a)
-#define xcAddTimeOut(a, b, c, d)	Tcl_CreateTimerHandler(b, c, d)
+#define xcAddTimeOut(a, b, c, d)	Tcl_CreateTimerHandler((int)(b), c, d)
 #define xcRemoveTimeOut			Tcl_DeleteTimerHandler
 #define xcTimeOutProc			Tcl_TimerProc *
 #define xcIntervalId			Tcl_TimerToken
@@ -1365,11 +1376,17 @@ typedef struct _undostack {
 
 typedef struct {
    char		*filename;	/* Last file loaded into the library */
+   char		flags;		/* Flags for library page (changed, read-only) */
    short	number;
    objectptr	*library;
    liblistptr	instlist;	/* List of instances */
 } Library;
 
+/* Known flags for library pages */
+
+#define LIBRARY_CHANGED		0x01
+#define LIBRARY_READONLY	0x02
+
 /*----------------------------------------------------------------------*/
 /* A convenient structure for holding all the object lists		*/
 /*----------------------------------------------------------------------*/
@@ -1384,6 +1401,7 @@ typedef struct {
    int		save_interval;
    short	do_replace;
    Boolean	filefilter;	/* Is the file list filtered? */
+   Boolean	hold;		/* allow HOLD modifiers on buttons */
    u_short	new_changes;
    short	numlibs;
    short	pages;
