@@ -24,6 +24,7 @@ extern void RegisterXPMImageType();
 
 extern int Tk_SimpleObjCmd();
 extern int xctcl_standardaction();
+extern int xctcl_action();
 extern int xctcl_refresh();
 extern int xctcl_library();
 extern int xctcl_font();
@@ -78,6 +79,7 @@ typedef struct {
 
 static cmdstruct xc_commands[] =
 {
+   {"action", (void *)xctcl_action},
    {"standardaction", (void *)xctcl_standardaction},
    {"start", (void *)xctcl_start},
    {"tag", (void *)xctcl_tag},
